@@ -426,6 +426,10 @@ class CachedQuerySetMixin(object):
         
 class CachedQuerySet(CachedQuerySetMixin, QuerySet):
     
+    def __init__(self, *args, **kwargs):
+        super(CachedQuerySet, self).__init__(*args, **kwargs)
+        self._reversemapping = {}
+    
     def iterator(self):    
         for obj in CacheBot(self):
             yield obj
@@ -438,8 +442,13 @@ class CachedQuerySet(CachedQuerySetMixin, QuerySet):
         post_update.send(sender=self.model, queryset=self)
         return super(CachedQuerySet, self).update(**kwargs)    
     
+    
 class CachedValuesQuerySet(CachedQuerySetMixin, ValuesQuerySet):
     
+    def __init__(self, *args, **kwargs):
+        super(CachedValuesQuerySet, self).__init__(*args, **kwargs)
+        self._reversemapping = {}
+        
     def iterator(self):      
         for obj in CacheBot(self):
             yield obj
@@ -451,4 +460,4 @@ class CachedValuesQuerySet(CachedQuerySetMixin, ValuesQuerySet):
     def update(self, **kwargs):
         post_update.send(sender=self.model, queryset=self)
         return super(CachedQuerySet, self).update(**kwargs)  
-    
\ No newline at end of file
+
